pub enum Error {
Io(Error),
Goblin(Error),
Scroll(Error),
Malformed(String),
ReplaceString {
original: String,
replacement: String,
},
UnknownObject,
FatBinaryUnsupported,
WrongSectionHeader(String),
PatchTooBig,
}Expand description
An error
Variants
Io(Error)
An I/O error
Goblin(Error)
An error from goblin, the binary parser
Scroll(Error)
An error from scroll, used by the binary parser
Malformed(String)
The loaded object is malformed
ReplaceString
Replacing a string failed
UnknownObject
The loaded object could not be recognized
FatBinaryUnsupported
Returned when loading a macOS fat binary
WrongSectionHeader(String)
The ELF section header did not match a symbol table
PatchTooBig
A patch was too big to insert into the binary